@@ -1,5 +1,5 @@
 package Net::Works::Network;
-$Net::Works::Network::VERSION = '0.19';
+$Net::Works::Network::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -10,6 +10,7 @@ use Net::Works::Address;
 use Net::Works::Types qw( IPInt PrefixLength NetWorksAddress Str );
 use Net::Works::Util
     qw( _integer_address_to_string _string_address_to_integer );
+use Scalar::Util qw( blessed );
 use Socket 1.99 qw( inet_pton AF_INET AF_INET6 );
 
 use integer;
@@ -21,6 +22,8 @@ use integer;
 
 use overload (
     q{""} => '_overloaded_as_string',
+    '<=>' => '_compare_overload',
+    'cmp' => '_compare_overload',
 );
 
 use Moo;
@@ -440,6 +443,25 @@ sub _max_subnet {
     );
 }
 
+sub _compare_overload {
+    my $self  = shift;
+    my $other = shift;
+
+    confess 'Cannot compare unless both objects are '
+        . __PACKAGE__
+        . ' objects'
+        unless blessed $self
+        && blessed $other
+        && eval { $self->isa(__PACKAGE__) && $other->isa(__PACKAGE__) };
+
+    my $cmp = (
+               $self->first() <=> $other->first()
+            or $self->prefix_length() <=> $other->prefix_length()
+    );
+
+    return shift() ? $cmp * -1 : $cmp;
+}
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
@@ -456,7 +478,7 @@ Net::Works::Network - An object representing a single IP address (4 or 6) subnet
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -647,6 +669,16 @@ When given an IPv6 range that includes the first 32 bits of addresses (the
 IPv4 space), both IPv4 I<and> IPv6 reserved networks are removed from the
 range.
 
+=head1 OVERLOADING
+
+This class overloads comparison, allowing you to compare two objects and to
+sort them (either as numbers or strings). Objects are compared based on the
+first IP address in their networks, and then by prefix length if they have the
+same starting address.
+
+It also overloads stringification to call the C<< $network->as_string() >>
+method.
+
 =head1 DEPRECATED METHODS AND ATTRIBUTES
 
 Prior to version 0.17, this package referred to the prefix length as mask
